pub struct NodeBusTopologyGetResponse {
pub path: Vec<BusInfo>,
}Fields
path: Vec<BusInfo>Trait Implementations
Sourceimpl Clone for NodeBusTopologyGetResponse
impl Clone for NodeBusTopologyGetResponse
Sourcefn clone(&self) -> NodeBusTopologyGetResponse
fn clone(&self) -> NodeBusTopologyGetResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeBusTopologyGetResponse
impl Debug for NodeBusTopologyGetResponse
Sourceimpl<___E> Encode<NodeBusTopologyGetResponse<'static>, ___E> for NodeBusTopologyGetResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<NodeBusTopologyGetResponse<'static>, ___E> for NodeBusTopologyGetResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NodeBusTopologyGetResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NodeBusTopologyGetResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<NodeBusTopologyGetResponse<'static>, ___E> for &'a NodeBusTopologyGetResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<NodeBusTopologyGetResponse<'static>, ___E> for &'a NodeBusTopologyGetResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NodeBusTopologyGetResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NodeBusTopologyGetResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, NodeBusTopologyGetResponse<'static>>, ___E> for NodeBusTopologyGetResponsewhere
___E: Encoder + ?Sized,
NodeBusTopologyGetResponse: Encode<NodeBusTopologyGetResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, NodeBusTopologyGetResponse<'static>>, ___E> for NodeBusTopologyGetResponsewhere
___E: Encoder + ?Sized,
NodeBusTopologyGetResponse: Encode<NodeBusTopologyGetResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<NodeBusTopologyGetResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, NodeBusTopologyGetResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<NodeBusTopologyGetResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, NodeBusTopologyGetResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, NodeBusTopologyGetResponse<'static>>, ___E> for &'a NodeBusTopologyGetResponsewhere
___E: Encoder + ?Sized,
&'a NodeBusTopologyGetResponse: Encode<NodeBusTopologyGetResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, NodeBusTopologyGetResponse<'static>>, ___E> for &'a NodeBusTopologyGetResponsewhere
___E: Encoder + ?Sized,
&'a NodeBusTopologyGetResponse: Encode<NodeBusTopologyGetResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a NodeBusTopologyGetResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, NodeBusTopologyGetResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a NodeBusTopologyGetResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, NodeBusTopologyGetResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<NodeBusTopologyGetResponse<'de>> for NodeBusTopologyGetResponse
impl<'de> FromWire<NodeBusTopologyGetResponse<'de>> for NodeBusTopologyGetResponse
Sourcefn from_wire(
wire: NodeBusTopologyGetResponse<'de>,
) -> NodeBusTopologyGetResponse
fn from_wire( wire: NodeBusTopologyGetResponse<'de>, ) -> NodeBusTopologyGetResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<NodeBusTopologyGetResponse<'de>> for NodeBusTopologyGetResponse
impl<'de> FromWireRef<NodeBusTopologyGetResponse<'de>> for NodeBusTopologyGetResponse
Sourcefn from_wire_ref(
wire: &NodeBusTopologyGetResponse<'de>,
) -> NodeBusTopologyGetResponse
fn from_wire_ref( wire: &NodeBusTopologyGetResponse<'de>, ) -> NodeBusTopologyGetResponse
Converts the given reference to this type.
impl StructuralPartialEq for NodeBusTopologyGetResponse