NodeToken

Struct NodeToken 

pub struct NodeToken;
The type corresponding to the NodeToken protocol. A protocol that is meant to be composed into other protocols to allow driver clients to query the node token associated with the driver. This token can be exchanged with the driver framework via protocols such as fuchsia.driver.token/NodeBusTopology.Get to learn more information about the node.