DebugServerHandler

Trait DebugServerHandler 

pub trait DebugServerHandler<___T: Transport = Channel> {
    // Required methods
    fn log_stack_trace(
        &mut self,
        request: Request<LogStackTrace, ___T>,
        responder: Responder<LogStackTrace, ___T>,
    ) -> impl Future<Output = ()> + Send;
    fn get_host_koid(
        &mut self,
        request: Request<GetHostKoid, ___T>,
        responder: Responder<GetHostKoid, ___T>,
    ) -> impl Future<Output = ()> + Send;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> + Send { ... }
}
A server handler for the Debug protocol.

See [Debug] for more details.

Required Methods

fn log_stack_trace( &mut self, request: Request<LogStackTrace, ___T>, responder: Responder<LogStackTrace, ___T>, ) -> impl Future<Output = ()> + Send

Triggers a log of a full stack trace for the host corresponding to a node uniquely identified by node_token.

fn get_host_koid( &mut self, request: Request<GetHostKoid, ___T>, responder: Responder<GetHostKoid, ___T>, ) -> impl Future<Output = ()> + Send

Returns the KOID of the host process for the node uniquely identified by node_token.

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors