#[repr(C)]pub struct DebugGetHostKoidRequest {
pub node_token: Event,
}Expand description
The wire type corresponding to DebugGetHostKoidRequest.
Fields
node_token: EventTrait Implementations
Sourceimpl Constrained for DebugGetHostKoidRequest
impl Constrained for DebugGetHostKoidRequest
Sourceimpl Debug for DebugGetHostKoidRequest
impl Debug for DebugGetHostKoidRequest
Sourceimpl<___D> Decode<___D> for DebugGetHostKoidRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DebugGetHostKoidRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DebugGetHostKoidRequest, ___E> for DebugGetHostKoidRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DebugGetHostKoidRequest, ___E> for DebugGetHostKoidRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DebugGetHostKoidRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DebugGetHostKoidRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DebugGetHostKoidRequest, ___E> for DebugGetHostKoidRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<DebugGetHostKoidRequest, ___E> for DebugGetHostKoidRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DebugGetHostKoidRequest> for DebugGetHostKoidRequest
impl FromWire<DebugGetHostKoidRequest> for DebugGetHostKoidRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidRequest, Self>
Sourcefn from_wire(wire: DebugGetHostKoidRequest) -> Self
fn from_wire(wire: DebugGetHostKoidRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DebugGetHostKoidRequest
impl IntoNatural for DebugGetHostKoidRequest
Sourcetype Natural = DebugGetHostKoidRequest
type Natural = DebugGetHostKoidRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DebugGetHostKoidRequest
impl Wire for DebugGetHostKoidRequest
Sourcetype Narrowed<'de> = DebugGetHostKoidRequest
type Narrowed<'de> = DebugGetHostKoidRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.