#[repr(C)]pub struct DebugGetHostKoidResponse {
pub host_koid: Uint64,
}Expand description
The wire type corresponding to DebugGetHostKoidResponse.
Fields
host_koid: Uint64Trait Implementations
Sourceimpl Clone for DebugGetHostKoidResponse
impl Clone for DebugGetHostKoidResponse
Sourcefn clone(&self) -> DebugGetHostKoidResponse
fn clone(&self) -> DebugGetHostKoidResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DebugGetHostKoidResponse
impl Constrained for DebugGetHostKoidResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DebugGetHostKoidResponse>,
_: <DebugGetHostKoidResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DebugGetHostKoidResponse>, _: <DebugGetHostKoidResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DebugGetHostKoidResponse
impl Debug for DebugGetHostKoidResponse
Sourceimpl<___D> Decode<___D> for DebugGetHostKoidResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DebugGetHostKoidResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<DebugGetHostKoidResponse, ___E> for DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DebugGetHostKoidResponse, ___E> for DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidResponse, DebugGetHostKoidResponse>
const COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidResponse, DebugGetHostKoidResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DebugGetHostKoidResponse, ___E> for &'a DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DebugGetHostKoidResponse, ___E> for &'a DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<DebugGetHostKoidResponse, ___E> for DebugGetHostKoidResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<DebugGetHostKoidResponse, ___E> for DebugGetHostKoidResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
impl FromWire<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidResponse, DebugGetHostKoidResponse>
const COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidResponse, DebugGetHostKoidResponse>
Sourcefn from_wire(wire: DebugGetHostKoidResponse) -> DebugGetHostKoidResponse
fn from_wire(wire: DebugGetHostKoidResponse) -> DebugGetHostKoidResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
impl FromWireRef<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
Sourcefn from_wire_ref(wire: &DebugGetHostKoidResponse) -> DebugGetHostKoidResponse
fn from_wire_ref(wire: &DebugGetHostKoidResponse) -> DebugGetHostKoidResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DebugGetHostKoidResponse
impl IntoNatural for DebugGetHostKoidResponse
Sourcetype Natural = DebugGetHostKoidResponse
type Natural = DebugGetHostKoidResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DebugGetHostKoidResponse
impl Wire for DebugGetHostKoidResponse
Sourcetype Narrowed<'de> = DebugGetHostKoidResponse
type Narrowed<'de> = DebugGetHostKoidResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DebugGetHostKoidResponse>)
fn zero_padding(out_: &mut MaybeUninit<DebugGetHostKoidResponse>)
Writes zeroes to the padding for this type, if any.