#[repr(C)]pub struct DebugLogStackTraceRequest {
pub node_token: Event,
}Expand description
The wire type corresponding to DebugLogStackTraceRequest.
Fields
node_token: EventTrait Implementations
Sourceimpl Constrained for DebugLogStackTraceRequest
impl Constrained for DebugLogStackTraceRequest
Sourceimpl Debug for DebugLogStackTraceRequest
impl Debug for DebugLogStackTraceRequest
Sourceimpl<___D> Decode<___D> for DebugLogStackTraceRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DebugLogStackTraceRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DebugLogStackTraceRequest, ___E> for DebugLogStackTraceRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DebugLogStackTraceRequest, ___E> for DebugLogStackTraceRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DebugLogStackTraceRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DebugLogStackTraceRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugLogStackTraceRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugLogStackTraceRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DebugLogStackTraceRequest, ___E> for DebugLogStackTraceRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<DebugLogStackTraceRequest, ___E> for DebugLogStackTraceRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugLogStackTraceRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugLogStackTraceRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DebugLogStackTraceRequest> for DebugLogStackTraceRequest
impl FromWire<DebugLogStackTraceRequest> for DebugLogStackTraceRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DebugLogStackTraceRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DebugLogStackTraceRequest, Self>
Sourcefn from_wire(wire: DebugLogStackTraceRequest) -> Self
fn from_wire(wire: DebugLogStackTraceRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DebugLogStackTraceRequest
impl IntoNatural for DebugLogStackTraceRequest
Sourcetype Natural = DebugLogStackTraceRequest
type Natural = DebugLogStackTraceRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DebugLogStackTraceRequest
impl Wire for DebugLogStackTraceRequest
Sourcetype Narrowed<'de> = DebugLogStackTraceRequest
type Narrowed<'de> = DebugLogStackTraceRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.