#[repr(C)]pub struct NodeBusTopologyGetRequest {
pub token: Event,
}Expand description
The wire type corresponding to NodeBusTopologyGetRequest.
Fields
token: EventTrait Implementations
Sourceimpl Constrained for NodeBusTopologyGetRequest
impl Constrained for NodeBusTopologyGetRequest
Sourceimpl Debug for NodeBusTopologyGetRequest
impl Debug for NodeBusTopologyGetRequest
Sourceimpl<___D> Decode<___D> for NodeBusTopologyGetRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for NodeBusTopologyGetRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<NodeBusTopologyGetRequest, ___E> for NodeBusTopologyGetRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<NodeBusTopologyGetRequest, ___E> for NodeBusTopologyGetRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, NodeBusTopologyGetRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, NodeBusTopologyGetRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NodeBusTopologyGetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NodeBusTopologyGetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<NodeBusTopologyGetRequest, ___E> for NodeBusTopologyGetRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<NodeBusTopologyGetRequest, ___E> for NodeBusTopologyGetRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NodeBusTopologyGetRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NodeBusTopologyGetRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<NodeBusTopologyGetRequest> for NodeBusTopologyGetRequest
impl FromWire<NodeBusTopologyGetRequest> for NodeBusTopologyGetRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<NodeBusTopologyGetRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<NodeBusTopologyGetRequest, Self>
Sourcefn from_wire(wire: NodeBusTopologyGetRequest) -> Self
fn from_wire(wire: NodeBusTopologyGetRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for NodeBusTopologyGetRequest
impl IntoNatural for NodeBusTopologyGetRequest
Sourcetype Natural = NodeBusTopologyGetRequest
type Natural = NodeBusTopologyGetRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for NodeBusTopologyGetRequest
impl Wire for NodeBusTopologyGetRequest
Sourcetype Narrowed<'de> = NodeBusTopologyGetRequest
type Narrowed<'de> = NodeBusTopologyGetRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.